/* eslint-disable no-console */export function findConverterForNode({
  converters,
  disableIndent,
  disableTextAlign,
  node,
  unknownConverter
}) {
  let converterForNode;
  if (node.type === 'block') {
    converterForNode = converters?.blocks?.[node?.fields?.blockType];
    if (!converterForNode && !unknownConverter) {
      console.error(`Lexical => HTML converter: Blocks converter: found ${node?.fields?.blockType} block, but no converter is provided`);
    }
  } else if (node.type === 'inlineBlock') {
    converterForNode = converters?.inlineBlocks?.[node?.fields?.blockType];
    if (!converterForNode && !unknownConverter) {
      console.error(`Lexical => HTML converter: Inline Blocks converter: found ${node?.fields?.blockType} inline block, but no converter is provided`);
    }
  } else {
    converterForNode = converters[node.type];
  }
  const style = {};
  // Check if disableTextAlign is not true and does not include node type
  if (!disableTextAlign && (!Array.isArray(disableTextAlign) || !disableTextAlign?.includes(node.type))) {
    if ('format' in node && node.format) {
      switch (node.format) {
        case 'center':
          style['text-align'] = 'center';
          break;
        case 'end':
          style['text-align'] = 'right';
          break;
        case 'justify':
          style['text-align'] = 'justify';
          break;
        case 'left':
          break;
        case 'right':
          style['text-align'] = 'right';
          break;
        case 'start':
          style['text-align'] = 'left';
          break;
      }
    }
  }
  if (!disableIndent && (!Array.isArray(disableIndent) || !disableIndent?.includes(node.type))) {
    if ('indent' in node && node.indent && node.type !== 'listitem') {
      style['padding-inline-start'] = `${Number(node.indent) * 2}em`;
    }
  }
  let providedCSSString = '';
  for (const key of Object.keys(style)) {
    // @ts-expect-error we're iterating over the keys of the object
    providedCSSString += `${key}: ${style[key]};`;
  }
  const providedStyleTag = providedCSSString?.length ? ` style="${providedCSSString}"` : '';
  return {
    converterForNode: converterForNode ?? unknownConverter,
    providedCSSString,
    providedStyleTag
  };
}
//# sourceMappingURL=findConverterForNode.js.map